<template>
  <view>
    <view class="nav_item form-container">
      <form :modelValue="formData">
        <view class="form-group">
          <label class="form-label">目标库位:</label>
          <input class="form-input" :focus="focus1" placeholder="请输入库位编码或者扫描库位二维码" type="text"
                 v-model="formData.sectionCode" @focus="getFocus" @confirm="ccc"/>
        </view>
        <view class="form-group">
          <label class="form-label">仓库:</label>
          <input class="form-input" disabled="true" type="text" v-model="formData.depot"/>
        </view>
        <view class="form-group">
          <label class="form-label">库位:</label>
          <input class="form-input" disabled="true" type="text" v-model="formData.sectionName"/>
        </view>
        <view class="form-group">
          <label class="form-label">物料条码:</label>
          <input class="form-input" :focus="focus2" placeholder="请扫描物料条码" type="text"
                 v-model="formData.barcode" @focus="ccc"/>
        </view>
        <view class="form-group">
          <label class="form-label">物料编码:</label>
          <input class="form-input" disabled="true" type="text" v-model="formData.itemNo"/>
        </view>
        <view class="form-group">
          <label class="form-label">数量:</label>
          <input class="form-input" disabled="true" type="text" v-model="formData.quantity"/>
        </view>
      </form>
    </view>
    <view class="plus-button">
      <button type="warn" @click="SaveBarCodes">确认</button>
    </view>
  </view>
</template>
<script>
import {
  broadcastScan
} from '@/utils/scanCode.js';

export default {
  data() {
    return {
      formData: {
        sectionCode: "",
        barcode: "",
        sectionName: ""
      },
      Message: "",
      messageCenter: {},
      messageId: 0,
      showClearIcon: false,
      focus1: true,
      focus2: false,
      tableData: null,
      itemTableData: null,
      isActive: 0,
      index: 0,
      currentTab: 0,
      contentScrollW: 0, // 导航区宽度
      scrollLeft: 0, // 横向滚动条位置
      fullHeight: "",
      itemInsFormData: {}
    }
  },
  methods: {
    changeTab(index) {
      this.currentTab = index;
    },
    getFocus() {
      this.focus1 = true;
      this.focus2 = false;
    },
    ccc() {
      //MesDepotSections
      this.$post({
        url: "/MesDepotSections/GetSectionName",
        data: {
          sectionCode: this.formData.sectionCode
        }
      }).then(res => {
        let sectionName = res.data.tbBillList;
        if (sectionName) {
          this.formData.sectionName = res.data.tbBillList;
          this.focus2 = true;
          this.focus1 = false;
        } else {
          this.formData.sectionName = "";
        }
      });
    },
    // 自定义扫描的结果回调函数
    getScanCode(code) {
      let parseData = code.trim();
      console.log('自定义扫描的结果回调函数:' + parseData);
      if (this.focus2) {
        this.formData.barcode = parseData;
        this.SaveBarCodes();
      } else {
        this.formData.sectionCode = parseData;
        this.ccc();
      }
    },
    // 主动触发扫描
    openScan() {
      broadcastScan.triggerScan();
    },
    SaveBarCodes() {
      this.formData.userName = this.$loginInfo.account;
      this.$post({
        url: '/OpeningReceipt/ScanInBarcodeQC',
        data: this.formData
      }).then(res => {
        console.log(res.data.tbBillList);

        this.formData.itemNo = res.data.tbBillList.itemNo;
        this.formData.quantity = res.data.tbBillList.quantity;
        this.getTable();
        this.formData.barcode = "";
      })
    },
    getTable() {
      this.$post({
        url: '/OpeningReceipt/GetForm',
        data: this.formData
      }).then(res => {
        console.log(res.data.tbBillList);
        this.itemTableData = res.data.tbBillList.itemStocks;
        this.tableData = res.data.tbBillList.invItemInCDetails;
        this.itemInsFormData = res.data.tbBillList.itemIns
      });
    }
  },
  // onLoad 是在页面加载时触发，用于页面的初始化操作，只执行一次
  onLoad() {
    // init传入一个回调函数做参数，在扫描时候会将数据传入此方法里，然后处理此方法的自定义业务逻辑
    broadcastScan.init(this.getScanCode);
  },
  onUnload() {
    broadcastScan.stop();
  },
  // 在页面展示时触发，用于处理页面显示相关的逻辑，可能会多次执行，包括页面首次展示和从后台切换到前台时
  onShow() {
    broadcastScan.start();
  },
  onHide() {
    broadcastScan.stop();
  },
}
</script>
<style lang="scss">
.form-group {
  display: flex;
  align-items: center;
  border-bottom: 1px solid #c9c9c9;
}

.form-label {
  margin-bottom: 0;
  padding: 5px;
}

.form-input {
  flex: 1;
  margin-bottom: 0;
  padding: 5px;
}

.picker {
  flex: 1;
  margin-bottom: 0;
  padding: 5px;
  font-size: 12px;
}

.uni-form-item {
  display: flex;
  border-bottom: 1px solid #c9c9c9;
}

.edit {
  background-color: white;
}

/* 默认样式 */
.list-container {
  height: 60vh;
  /* 设置列表容器的高度为剩余空间，并减去表单容器的高度 */
  overflow-y: auto;
  /* 允许列表容器垂直滚动 */
  padding: 10px;
  /* 可选：添加一些内边距，使列表内容更美观 */
}

/* 在小屏幕设备上，重置高度为适应屏幕 */
@media (max-width: 768px) {
  .list-container {
    height: calc(100vh - 500px);
    /* 适当调整高度 */
  }
}

.form-container {
  padding: 10px;
  /* 可选：添加一些内边距，使表单内容更美观 */
}

.th {
  background-color: lightskyblue;
  color: #FFFFFF;
}

.text {
  background-color: #ffee6f;
}

.plus-button {
  line-height: 59px;
  font-size: 24px;
  cursor: pointer;
  z-index: 1000;
  margin-bottom: 10px;
}

.overlay {
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background-color: rgba(0, 0, 0, 0.5);
  display: flex;
  justify-content: center;
  align-items: center;
}

.popup {
  background-color: #fff;
  padding: 20px;
  border: 1px solid #ccc;
  box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
  width: 68vw;
  /* 设置宽度为视口宽度的80% */
  height: 25vh;
  /* 设置高度为视口高度的80% */
}

.container {
  display: flex;
  flex-direction: column;
}

.tab-bar {
  display: flex;
  justify-content: space-around;
  background-color: #f5f5f5;
  padding: 10px;
  border-bottom: 1px solid #ccc;
}

.tab-item {
  flex: 1;
  text-align: center;
  padding: 10px;
  border-radius: 5px;
  background-color: #fff;
  color: #007aff;
  cursor: pointer;
  font-size: 16px;
  transition: background-color 0.3s, color 0.3s;
}

.tab-item.active {
  background-color: #007aff;
  color: #fff;
  font-weight: bold;
}

.content {
  flex: 1;
  padding: 10px;
}

.tab-content {
  padding: 10px;
}
</style>